pub struct Kretprobe { /* private fields */ }Expand description
A Kretprobe is used to configure and then attach a probe to a kernel
function which runs on return from that function. Must be attached to be
useful.
Implementations
Sourceimpl Kretprobe
impl Kretprobe
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new probe with the defaults. Further initialization is required before attaching.
Sourcepub fn handler(self, name: &str) -> Self
pub fn handler(self, name: &str) -> Self
Specify the name of the probe handler within the BPF code. This is a required item.